import { Matrix4, Object3D } from "three";
/** 力场形状 */
export declare enum ForceShape {
    POINT = 0,
    LINE = 1,
    PLANE = 2,
    SURFACE = 3,
    POINTS = 4
}
/** 衰减形状 */
export declare enum FalloffType {
    CONE = 0,
    SPHERE = 1,
    TUBE = 2
}
/** 衰减z向 */
export declare enum FalloffZ {
    BOTH = 0,
    POSITIVE = 1,
    NEGATIVE = 2
}
/** 扭结类型 */
export declare enum KinkType {
    NONE = 0,
    WAVE = 1,
    ROTATION = 2,
    ROLL = 3,
    RADIAL = 4,
    CURL = 5,
    BRAID = 6
}
/** 扭结轴向 */
export declare enum KinkAxis {
    X = 0,
    Y = 1,
    Z = 2
}
/** 纹理模式 */
export declare enum TextureMode {
    CURL = 0,
    GRADIENT = 1,
    RGB = 2
}
/** 力场公共逻辑 */
export declare class DefaultForce {
    #private;
    [key: string]: any;
    static type: string;
    get type(): string;
    get name(): string;
    get structName(): string;
    get uniformName(): string;
    get uniformCountName(): string;
    /** 力场的世界变换矩阵 */
    matrixWorld: Matrix4;
    /** 力场是否是自身 */
    isSelf: boolean;
    get shaderStruct(): string;
    constructor(object: Object3D);
    protected init(): void;
}
/** 公共力场参数 */
export declare class CommonForce extends DefaultForce {
    static type: string;
    get type(): string;
    apply_rotation: boolean;
    falloff_type: FalloffType;
    z_direction: FalloffZ;
    falloff_power: number;
    distance_min: number;
    distance_max: number;
    use_distance_min: boolean;
    use_distance_max: boolean;
}
/** 常用力场参数 */
export declare class BaseForce extends CommonForce {
    static type: string;
    get type(): string;
    shape: ForceShape;
    strength: number;
    flow: number;
    apply_location: boolean;
    noise: number;
    absorption: boolean;
    wind: number;
}
