import { GLTFLoader } from 'three/examples/jsm/loaders/GLTFLoader';
import { LoadingManager } from 'three';
import { SceneGLTF } from './plugin';
/**
 * GlTF 加载器，继承 [`THREE.GLTFLoader`](https://threejs.org/docs/index.html?q=GLTFLoader#examples/en/loaders/GLTFLoader)
 *
 *  ```ts
import {TencentGLTFLoader} from 'tencent3d';
new TencentGLTFLoader().load(
  src: './untitled.glb',
    (gltf) => {
    // `gltf.scene`类型已改为`THREE.Scene`类型，添加到其他`Scene`时，请按下方代码形式进行添加。
        scene.add(...gltf.scene.children);
        gltf.animations;    // Array<THREE.AnimationClip>
        gltf.scene;         // THREE.Scene
        gltf.camera;        // THREE.Camera 增加`gltf.camera`属性，代表当前激活的相机
        gltf.scenes;        // Array<THREE.Scene>
        gltf.cameras;       // Array<THREE.Camera>
        gltf.asset;         // Object
    },
    function ( xhr ) {
        console.log( ( xhr.loaded / xhr.total * 100 ) + '% loaded' );
    },
    function ( error ) {
        console.log( 'An error happened' );
    }
);
 * ```
 */
export default class TencentGLTFLoader extends GLTFLoader {
    constructor(manager?: LoadingManager);
    load(url: string, onLoad: (gltf: SceneGLTF) => void, onProgress?: (event: ProgressEvent) => void, onError?: (event: ErrorEvent) => void): void;
    loadAsync(url: string, onProgress?: (event: ProgressEvent) => void): Promise<SceneGLTF>;
}
