/** eslint-disable no-restricted-properties */
/** eslint-disable @typescript-eslint/no-unused-vars */
import { BufferGeometry, Camera, Group, Mesh, Scene, ShaderMaterial, ShaderMaterialParameters, WebGLRenderer, Texture, Combine } from 'three';
import { SocketType } from './shaderNode/ShaderNode';
import ShaderNodeTree, { ShaderNodeTreeParams } from './ShaderNodeTree';
/** [绘制模式](https://developer.mozilla.org/zh-CN/docs/Web/API/WebGLRenderingContext/drawElements#%E5%8F%82%E6%95%B0) */
declare enum DrawMode {
    POINTS = 0,
    LINE_STRIP = 1,
    LINE_LOOP = 2,
    LINES = 3,
    TRIANGLES = 4
}
export interface ShaderNodeMaterialParams extends ShaderNodeTreeParams, ShaderMaterialParameters {
    castShadow?: boolean;
    receiveShadow?: boolean;
    pointSize?: number;
    pointAttenuation?: boolean;
    abbe?: number;
    drawMode?: 'POINTS' | 'LINE_STRIP' | 'LINE_LOOP' | 'LINES' | 'TRIANGLES';
    transparentBack: boolean;
}
declare const nodeParams: unique symbol;
declare const symbolEnv: unique symbol;
declare const symbolCacheKey: unique symbol;
/**
 * # Blender ShaderNode 材质
 * `Tencent3D`实例中的`THREE.Mesh`物体采用此材质.
 *
 */
export default class ShaderNodeMaterial extends ShaderMaterial {
    /** 是否已销毁 */
    isDestory: boolean;
    /** @ignore */
    isMeshStandardMaterial: boolean;
    /** @ignore */
    private [nodeParams];
    readonly type = "ShaderNodeMaterial";
    /** Blender 节点树 */
    nodeTree: ShaderNodeTree;
    /** @ignore */
    defines: {
        [key: string]: string;
    };
    /** @ignore */
    extensions: {
        derivatives: boolean;
        fragDepth: boolean;
        drawBuffers: boolean;
        shaderTextureLOD: boolean;
    };
    /** @readonly 是否需要灯光 */
    lights: boolean;
    /** @readonly 是否需要清漆 */
    clearcoat: boolean;
    /** @readonly 是否需要丝绒材质 */
    sheen: boolean;
    /** @ignore @readonly 是否需要顶点颜色 */
    vertexColors: boolean;
    /** @ignore @readonly 是否需要UV数据 */
    vertexUvs: boolean;
    /** @ignore @readonly 是否需要切向数据 */
    vertexTangents: boolean;
    /** @ignore  */
    [symbolEnv]: Texture;
    /** 环境贴图 */
    envMap: Texture;
    /** @ignore */
    combine: Combine;
    castShadow: boolean;
    receiveShadow: boolean;
    /** 环境贴图强度 */
    get envMapIntensity(): number;
    set envMapIntensity(val: number);
    get abbe(): number;
    set abbe(val: number | undefined);
    aoMap: Texture;
    /** ao强度 */
    get aoMapIntensity(): number;
    set aoMapIntensity(val: number);
    /** 顶点模式时的点大小 */
    get pointSize(): number;
    set pointSize(val: number);
    get pointAttenuation(): boolean;
    set pointAttenuation(val: boolean);
    /** @readonly 绘制模式 */
    drawMode: DrawMode;
    constructor(nodesParams: ShaderNodeMaterialParams);
    clone(force?: boolean): this;
    dispose(): void;
    /** @ignore */
    private [symbolCacheKey];
    customProgramCacheKey(): string;
    /** @ignore */
    private static generateEnvMapTypeDefine;
    /** @ignore */
    private static generateEnvMapBlendingDefine;
    /** @ignore */
    private static generateCubeUVSize;
    /**
     * @event
     * 编译回调
     */
    onBeforeCompile(shader: ShaderNodeMaterial, renderer: WebGLRenderer): void;
    setUniform(key: string, value: SocketType): void;
    getUniform(key: string): import("./shaderNode/ShaderNode").SocketTypeAll | null;
    /** 设置绘制模式 */
    private setMode;
    /**
     * @event
     * 每次渲染物体执行一次
     */
    onBeforeRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, geometry: BufferGeometry, object: Mesh, group: Group): void;
    /**
     * @event
     * 每次eventLoop执行一次
     */
    onUpdate(renderer: WebGLRenderer, scene: Scene, camera: Camera): void;
}
export {};
