import ShaderNodeTree from '../ShaderNodeTree';
import ShaderNode, { NodeSocket, ShaderNodeParams, SocketType } from './ShaderNode';
export interface AmbientOcclusionParams<T> extends ShaderNodeParams<T> {
    /** Trace rays towards the inside of the object */
    inside: boolean;
    /** Only consider the object itself when computing AO */
    only_local: boolean;
    /** Number of rays to trace per shader evaluation */
    samples: number;
}
/**
 * Compute how much the hemisphere above the shading point is occluded, for example
 * to add weathering effects to corners.
 * Note: For Cycles, this may slow down renders significantly
 */
export default class AmbientOcclusion extends ShaderNode implements AmbientOcclusionParams<NodeSocket> {
    readonly inside: AmbientOcclusionParams<NodeSocket>['inside'];
    readonly only_local: AmbientOcclusionParams<NodeSocket>['only_local'];
    readonly samples: AmbientOcclusionParams<NodeSocket>['samples'];
    constructor(params: AmbientOcclusionParams<SocketType>, nodeTree: ShaderNodeTree);
    get defaultUniform(): Map<string, NodeSocket>;
    get parsShader(): string;
}
