import ShaderNodeTree from '../ShaderNodeTree';
import ShaderNode, { NodeSocket, ShaderNodeParams, SocketType } from './ShaderNode';
import { WebGLRenderer } from 'three';
import ShaderNodeMaterial from '../ShaderNodeMaterial';
import { Scene, Camera, Mesh, BufferGeometry, Group } from 'three';
export interface BsdfHairPrincipledParams<T> extends ShaderNodeParams<T> {
    /** Select the shader’s color parametrization */
    parametrization: 'ABSORPTION' | 'MELANIN' | 'COLOR';
}
/** Physically-based, easy-to-use shader for rendering hair and fur */
export default class BsdfHairPrincipled extends ShaderNode implements BsdfHairPrincipledParams<NodeSocket> {
    readonly parametrization: BsdfHairPrincipledParams<NodeSocket>['parametrization'];
    get weight(): number;
    set weight(val: number);
    constructor(params: BsdfHairPrincipledParams<SocketType>, nodeTree: ShaderNodeTree);
    get defaultUniform(): Map<string, NodeSocket>;
    get parsShader(): string;
    onBeforeObjectRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, object: Mesh, geometry: BufferGeometry, material: ShaderNodeMaterial, group: Group): void;
    onBeforeRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, material: ShaderNodeMaterial): void;
}
