import ShaderNodeTree from '../ShaderNodeTree';
import ShaderNode, { NodeSocket, ShaderNodeParams, SocketType } from './ShaderNode';
import { WebGLRenderer } from 'three';
import ShaderNodeMaterial from '../ShaderNodeMaterial';
import { Scene, Camera, Mesh, BufferGeometry, Group } from 'three';
export interface BsdfPrincipledParams<T> extends ShaderNodeParams<T> {
    /** Light scattering distribution on rough surface */
    distribution: 'GGX' | 'MULTI_GGX';
    /** Method for rendering subsurface scattering */
    subsurface_method: 'BURLEY' | 'RANDOM_WALK_FIXED_RADIUS' | 'RANDOM_WALK';
}
/**
 * Physically-based, easy-to-use shader for rendering surface materials, based on
 * the Disney principled model also known as the “PBR” shader
 */
export default class BsdfPrincipled extends ShaderNode implements BsdfPrincipledParams<NodeSocket> {
    readonly distribution: BsdfPrincipledParams<NodeSocket>['distribution'];
    readonly subsurface_method: BsdfPrincipledParams<NodeSocket>['subsurface_method'];
    get weight(): number;
    set weight(val: number);
    constructor(params: BsdfPrincipledParams<SocketType>, nodeTree: ShaderNodeTree);
    get defaultUniform(): Map<string, NodeSocket>;
    get parsShader(): string;
    onBeforeObjectRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, object: Mesh, geometry: BufferGeometry, material: ShaderNodeMaterial, group: Group): void;
    onBeforeRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, material: ShaderNodeMaterial): void;
}
