import ShaderNodeTree from '../ShaderNodeTree';
import ShaderNode, { NodeSocket, ShaderNodeParams, SocketType } from './ShaderNode';
import { WebGLRenderer } from 'three';
import ShaderNodeMaterial from '../ShaderNodeMaterial';
import { Scene, Camera } from 'three';
export interface BsdfRefractionParams<T> extends ShaderNodeParams<T> {
    /** Light scattering distribution on rough surface */
    distribution: 'SHARP' | 'BECKMANN' | 'GGX';
}
/**
 * Glossy refraction with sharp or microfacet distribution, typically used for
 * materials that transmit light
 */
export default class BsdfRefraction extends ShaderNode implements BsdfRefractionParams<NodeSocket> {
    readonly distribution: BsdfRefractionParams<NodeSocket>['distribution'];
    get weight(): number;
    set weight(val: number);
    constructor(params: BsdfRefractionParams<SocketType>, nodeTree: ShaderNodeTree);
    get defaultUniform(): Map<string, NodeSocket>;
    get parsShader(): string;
    onBeforeRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, material: ShaderNodeMaterial): void;
}
