import ShaderNodeTree from '../ShaderNodeTree';
import ShaderNode, { NodeSocket, ShaderNodeParams, SocketType } from './ShaderNode';
export interface MixParams<T> extends ShaderNodeParams<T> {
    blend_type: 'MIX' | 'DARKEN' | 'MULTIPLY' | 'BURN' | 'LIGHTEN' | 'SCREEN' | 'DODGE' | 'ADD' | 'OVERLAY' | 'SOFT_LIGHT' | 'LINEAR_LIGHT' | 'DIFFERENCE' | 'SUBTRACT' | 'DIVIDE' | 'HUE' | 'SATURATION' | 'COLOR' | 'VALUE';
    /** Clamp the factor to [0,1] range */
    clamp_factor: boolean;
    /** Clamp the result to [0,1] range */
    clamp_result: boolean;
    data_type: 'FLOAT' | 'VECTOR' | 'RGBA';
    factor_mode: 'UNIFORM' | 'NON_UNIFORM';
}
/** Mix values by a factor */
export default class Mix extends ShaderNode implements MixParams<NodeSocket> {
    readonly blend_type: MixParams<NodeSocket>['blend_type'];
    readonly clamp_factor: MixParams<NodeSocket>['clamp_factor'];
    readonly clamp_result: MixParams<NodeSocket>['clamp_result'];
    readonly data_type: MixParams<NodeSocket>['data_type'];
    readonly factor_mode: MixParams<NodeSocket>['factor_mode'];
    get type(): string;
    constructor(params: MixParams<SocketType>, nodeTree: ShaderNodeTree);
    get defaultUniform(): Map<string, NodeSocket>;
    get parsShader(): string;
}
