import ShaderNodeTree from '../ShaderNodeTree';
import ShaderNode, { NodeSocket, ShaderNodeParams, SocketType } from './ShaderNode';
import { WebGLRenderer } from 'three';
import ShaderNodeMaterial from '../ShaderNodeMaterial';
import { Scene, Camera, Mesh, BufferGeometry, Group } from 'three';
export interface NormalMapParams<T> extends ShaderNodeParams<T> {
    /** Space of the input normal */
    space: 'TANGENT' | 'OBJECT' | 'WORLD' | 'BLENDER_OBJECT' | 'BLENDER_WORLD';
    /** UV Map for tangent space maps */
    uv_map: string;
}
/**
 * Generate a perturbed normal from an RGB normal map image. Typically used for
 * faking highly detailed surfaces
 */
export default class NormalMap extends ShaderNode implements NormalMapParams<NodeSocket> {
    readonly space: NormalMapParams<NodeSocket>['space'];
    readonly uv_map: NormalMapParams<NodeSocket>['uv_map'];
    get type(): string;
    constructor(params: NormalMapParams<SocketType>, nodeTree: ShaderNodeTree);
    get parsShader(): string;
    onBeforeObjectRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, object: Mesh, geometry: BufferGeometry, material: ShaderNodeMaterial, group: Group): void;
}
