import ShaderNodeTree from '../ShaderNodeTree';
import ShaderNode, { NodeSocket, ShaderNodeParams, SocketType } from './ShaderNode';
import { WebGLRenderer } from 'three';
import ShaderNodeMaterial from '../ShaderNodeMaterial';
import { Scene, Camera, Mesh, BufferGeometry, Group } from 'three';
export interface OutputMaterialParams<T> extends ShaderNodeParams<T> {
    /** True if this node is used as the active output */
    is_active_output: boolean;
    /** Which renderer and viewport shading types to use the shaders for */
    target: 'ALL' | 'EEVEE' | 'CYCLES';
}
/** Output surface material information for use in rendering */
export default class OutputMaterial extends ShaderNode implements OutputMaterialParams<NodeSocket> {
    readonly is_active_output: OutputMaterialParams<NodeSocket>['is_active_output'];
    readonly target: OutputMaterialParams<NodeSocket>['target'];
    constructor(params: OutputMaterialParams<SocketType>, nodeTree: ShaderNodeTree);
    get defaultUniform(): Map<string, NodeSocket>;
    get parsShader(): string;
    onBeforeObjectRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, object: Mesh, geometry: BufferGeometry, material: ShaderNodeMaterial, group: Group): void;
}
