import ShaderNodeTree from '../ShaderNodeTree';
import ShaderNode, { NodeSocket, ShaderNodeParams, SocketType } from './ShaderNode';
import { WebGLRenderer } from 'three';
import ShaderNodeMaterial from '../ShaderNodeMaterial';
import { Scene, Camera } from 'three';
export interface SubsurfaceScatteringParams<T> extends ShaderNodeParams<T> {
    /** Method for rendering subsurface scattering */
    falloff: 'BURLEY' | 'RANDOM_WALK_FIXED_RADIUS' | 'RANDOM_WALK';
}
/**
 * Subsurface multiple scattering shader to simulate light entering the surface and
 * bouncing internally.
 * Typically used for materials such as skin, wax, marble or milk
 */
export default class SubsurfaceScattering extends ShaderNode implements SubsurfaceScatteringParams<NodeSocket> {
    readonly falloff: SubsurfaceScatteringParams<NodeSocket>['falloff'];
    get weight(): number;
    set weight(val: number);
    constructor(params: SubsurfaceScatteringParams<SocketType>, nodeTree: ShaderNodeTree);
    get defaultUniform(): Map<string, NodeSocket>;
    get parsShader(): string;
    onBeforeRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, material: ShaderNodeMaterial): void;
}
