import ShaderNodeTree from '../ShaderNodeTree';
import ShaderNode, { NodeSocket, ShaderNodeParams, SocketType } from './ShaderNode';
import { WebGLRenderer } from 'three';
import ShaderNodeMaterial from '../ShaderNodeMaterial';
import { Scene, Camera, Mesh, BufferGeometry, Group } from 'three';
export interface TangentParams<T> extends ShaderNodeParams<T> {
    /** Axis for radial tangents */
    axis: 'X' | 'Y' | 'Z';
    /** Method to use for the tangent */
    direction_type: 'RADIAL' | 'UV_MAP';
    /** UV Map for tangent generated from UV */
    uv_map: string;
}
/** Generate a tangent direction for the Anisotropic BSDF */
export default class Tangent extends ShaderNode implements TangentParams<NodeSocket> {
    readonly axis: TangentParams<NodeSocket>['axis'];
    readonly direction_type: TangentParams<NodeSocket>['direction_type'];
    readonly uv_map: TangentParams<NodeSocket>['uv_map'];
    get type(): string;
    constructor(params: TangentParams<SocketType>, nodeTree: ShaderNodeTree);
    get parsShader(): string;
    onBeforeObjectRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, object: Mesh, geometry: BufferGeometry, material: ShaderNodeMaterial, group: Group): void;
    onBeforeRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, material: ShaderNodeMaterial): void;
}
