import ShaderNodeTree from '../ShaderNodeTree';
import ShaderNode, { NodeSocket, ShaderNodeParams, SocketType } from './ShaderNode';
import { WebGLRenderer } from 'three';
import ShaderNodeMaterial from '../ShaderNodeMaterial';
import { Scene, Camera } from 'three';
export interface TexEnvironmentParams<T> extends ShaderNodeParams<T> {
    image: any;
    /** Texture interpolation */
    interpolation: 'Linear' | 'Closest' | 'Cubic' | 'Smart';
    /** Projection of the input image */
    projection: 'EQUIRECTANGULAR' | 'MIRROR_BALL';
    colorspace: 'Filmic Log' | 'Linear' | 'Linear ACES' | 'Non-Color' | 'Raw' | 'sRGB' | 'XYZ';
    alpha_mode: 'STRAIGHT' | 'PREMUL' | 'CHANNEL_PACKED' | 'NONE';
}
/**
 * Sample an image file as an environment texture. Typically used to light the scene
 * with the background node
 */
export default class TexEnvironment extends ShaderNode implements TexEnvironmentParams<NodeSocket> {
    readonly image: TexEnvironmentParams<NodeSocket>['image'];
    readonly interpolation: TexEnvironmentParams<NodeSocket>['interpolation'];
    readonly projection: TexEnvironmentParams<NodeSocket>['projection'];
    readonly colorspace: TexEnvironmentParams<NodeSocket>['colorspace'];
    readonly alpha_mode: TexEnvironmentParams<NodeSocket>['alpha_mode'];
    constructor(params: TexEnvironmentParams<SocketType>, nodeTree: ShaderNodeTree);
    get defaultUniform(): Map<string, NodeSocket>;
    get parsShader(): string;
    onBeforeRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, material: ShaderNodeMaterial): void;
}
