import ShaderNodeTree from '../ShaderNodeTree';
import ShaderNode, { NodeSocket, ShaderNodeParams, SocketType } from './ShaderNode';
import { WebGLRenderer } from 'three';
import ShaderNodeMaterial from '../ShaderNodeMaterial';
import { Scene, Camera } from 'three';
export interface TexImageParams<T> extends ShaderNodeParams<T> {
    /** How the image is extrapolated past its original bounds */
    extension: 'REPEAT' | 'EXTEND' | 'CLIP';
    image: any;
    /** Texture interpolation */
    interpolation: 'Linear' | 'Closest' | 'Cubic' | 'Smart';
    /** Method to project 2D image on object with a 3D texture vector */
    projection: 'FLAT' | 'BOX' | 'SPHERE' | 'TUBE';
    /** For box projection, amount of blend to use between sides */
    projection_blend: number;
    colorspace: 'Filmic Log' | 'Linear' | 'Linear ACES' | 'Non-Color' | 'Raw' | 'sRGB' | 'XYZ';
    alpha_mode: 'STRAIGHT' | 'PREMUL' | 'CHANNEL_PACKED' | 'NONE';
}
/** Sample an image file as a texture */
export default class TexImage extends ShaderNode implements TexImageParams<NodeSocket> {
    readonly extension: TexImageParams<NodeSocket>['extension'];
    readonly image: TexImageParams<NodeSocket>['image'];
    readonly interpolation: TexImageParams<NodeSocket>['interpolation'];
    readonly projection: TexImageParams<NodeSocket>['projection'];
    readonly projection_blend: TexImageParams<NodeSocket>['projection_blend'];
    readonly colorspace: TexImageParams<NodeSocket>['colorspace'];
    readonly alpha_mode: TexImageParams<NodeSocket>['alpha_mode'];
    constructor(params: TexImageParams<SocketType>, nodeTree: ShaderNodeTree);
    get defaultUniform(): Map<string, NodeSocket>;
    get parsShader(): string;
    onBeforeRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, material: ShaderNodeMaterial): void;
}
