import ShaderNodeTree from '../ShaderNodeTree';
import ShaderNode, { NodeSocket, ShaderNodeParams, SocketType } from './ShaderNode';
import { WebGLRenderer } from 'three';
import ShaderNodeMaterial from '../ShaderNodeMaterial';
import { Scene, Camera, Mesh, BufferGeometry, Group } from 'three';
export interface TexMusgraveParams<T> extends ShaderNodeParams<T> {
    /** Number of dimensions to output noise for */
    musgrave_dimensions: '1D' | '2D' | '3D' | '4D';
    /** Type of the Musgrave texture */
    musgrave_type: 'MULTIFRACTAL' | 'RIDGED_MULTIFRACTAL' | 'HYBRID_MULTIFRACTAL' | 'FBM' | 'HETERO_TERRAIN';
}
/**
 * Generate fractal Perlin noise. Allows for greater control over how octaves are
 * combined than the Noise Texture node
 */
export default class TexMusgrave extends ShaderNode implements TexMusgraveParams<NodeSocket> {
    readonly musgrave_dimensions: TexMusgraveParams<NodeSocket>['musgrave_dimensions'];
    readonly musgrave_type: TexMusgraveParams<NodeSocket>['musgrave_type'];
    get type(): string;
    constructor(params: TexMusgraveParams<SocketType>, nodeTree: ShaderNodeTree);
    get parsShader(): string;
    onBeforeObjectRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, object: Mesh, geometry: BufferGeometry, material: ShaderNodeMaterial, group: Group): void;
    onBeforeRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, material: ShaderNodeMaterial): void;
}
