import ShaderNodeTree from '../ShaderNodeTree';
import ShaderNode, { NodeSocket, ShaderNodeParams, SocketType } from './ShaderNode';
export interface TexPointDensityParams<T> extends ShaderNodeParams<T> {
    /** Texture interpolation */
    interpolation: 'Closest' | 'Linear' | 'Cubic';
    /** Object to take point data from */
    object: string;
    /** Data to derive color results from */
    particle_color_source: 'PARTICLE_AGE' | 'PARTICLE_SPEED' | 'PARTICLE_VELOCITY';
    /** Particle System to render as points */
    particle_system: any;
    /** Point data to use as renderable point density */
    point_source: 'PARTICLE_SYSTEM' | 'OBJECT';
    /** Radius from the shaded sample to look for points within */
    radius: number;
    /** Resolution used by the texture holding the point density */
    resolution: number;
    /** Coordinate system to calculate voxels in */
    space: 'OBJECT' | 'WORLD';
    /** Vertex attribute to use for color */
    vertex_attribute_name: string;
    /** Data to derive color results from */
    vertex_color_source: 'VERTEX_COLOR' | 'VERTEX_WEIGHT' | 'VERTEX_NORMAL';
}
/** Generate a volumetric point for each particle or vertex of another object */
export default class TexPointDensity extends ShaderNode implements TexPointDensityParams<NodeSocket> {
    readonly interpolation: TexPointDensityParams<NodeSocket>['interpolation'];
    readonly object: TexPointDensityParams<NodeSocket>['object'];
    readonly particle_color_source: TexPointDensityParams<NodeSocket>['particle_color_source'];
    readonly particle_system: TexPointDensityParams<NodeSocket>['particle_system'];
    readonly point_source: TexPointDensityParams<NodeSocket>['point_source'];
    readonly radius: TexPointDensityParams<NodeSocket>['radius'];
    readonly resolution: TexPointDensityParams<NodeSocket>['resolution'];
    readonly space: TexPointDensityParams<NodeSocket>['space'];
    readonly vertex_attribute_name: TexPointDensityParams<NodeSocket>['vertex_attribute_name'];
    readonly vertex_color_source: TexPointDensityParams<NodeSocket>['vertex_color_source'];
    static readonly type = "TEX_POINTDENSITY";
    constructor(params: TexPointDensityParams<SocketType>, nodeTree: ShaderNodeTree);
    get defaultUniform(): Map<string, NodeSocket>;
    get parsShader(): string;
}
