import ShaderNodeTree from '../ShaderNodeTree';
import ShaderNode, { NodeSocket, ShaderNodeParams, SocketType, Vec3 } from './ShaderNode';
import { WebGLRenderer } from 'three';
import ShaderNodeMaterial from '../ShaderNodeMaterial';
import { Scene, Camera, Mesh, BufferGeometry, Group } from 'three';
export interface TexSkyParams<T> extends ShaderNodeParams<T> {
    /** Ground color that is subtly reflected in the sky */
    ground_albedo: number;
    /** Which sky model should be used */
    sky_type: 'PREETHAM' | 'HOSEK_WILKIE' | 'NISHITA';
    /** Direction from where the sun is shining */
    sun_direction: Vec3;
    /** Atmospheric turbidity */
    turbidity: number;
}
/** Generate a procedural sky texture */
export default class TexSky extends ShaderNode implements TexSkyParams<NodeSocket> {
    readonly ground_albedo: TexSkyParams<NodeSocket>['ground_albedo'];
    readonly sky_type: TexSkyParams<NodeSocket>['sky_type'];
    readonly sun_direction: TexSkyParams<NodeSocket>['sun_direction'];
    readonly turbidity: TexSkyParams<NodeSocket>['turbidity'];
    get type(): string;
    private get sun_angles();
    private get configX();
    private get configY();
    private get configZ();
    private get radiance();
    constructor(params: TexSkyParams<SocketType>, nodeTree: ShaderNodeTree);
    get defaultUniform(): Map<string, NodeSocket>;
    get parsShader(): string;
    onBeforeObjectRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, object: Mesh, geometry: BufferGeometry, material: ShaderNodeMaterial, group: Group): void;
    onBeforeRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, material: ShaderNodeMaterial): void;
}
