import ShaderNodeTree from '../ShaderNodeTree';
import ShaderNode, { NodeSocket, ShaderNodeParams, SocketType } from './ShaderNode';
import { WebGLRenderer } from 'three';
import ShaderNodeMaterial from '../ShaderNodeMaterial';
import { Scene, Camera, Mesh, BufferGeometry, Group } from 'three';
export interface TexVoronoiParams<T> extends ShaderNodeParams<T> {
    /** The distance metric used to compute the texture */
    distance: 'EUCLIDEAN' | 'MANHATTAN' | 'CHEBYCHEV' | 'MINKOWSKI';
    /** The Voronoi feature that the node will compute */
    feature: 'F1' | 'F2' | 'SMOOTH_F1' | 'DISTANCE_TO_EDGE' | 'N_SPHERE_RADIUS';
    /** Number of dimensions to output noise for */
    voronoi_dimensions: '1D' | '2D' | '3D' | '4D';
}
/**
 * Generate Worley noise based on the distance to random points. Typically used to
 * generate textures such as stones, water, or biological cells
 */
export default class TexVoronoi extends ShaderNode implements TexVoronoiParams<NodeSocket> {
    readonly distance: TexVoronoiParams<NodeSocket>['distance'];
    readonly feature: TexVoronoiParams<NodeSocket>['feature'];
    readonly voronoi_dimensions: TexVoronoiParams<NodeSocket>['voronoi_dimensions'];
    get type(): string;
    constructor(params: TexVoronoiParams<SocketType>, nodeTree: ShaderNodeTree);
    get defaultUniform(): Map<string, NodeSocket>;
    get parsShader(): string;
    onBeforeObjectRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, object: Mesh, geometry: BufferGeometry, material: ShaderNodeMaterial, group: Group): void;
    onBeforeRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, material: ShaderNodeMaterial): void;
}
