import ShaderNodeTree from '../ShaderNodeTree';
import ShaderNode, { NodeSocket, ShaderNodeParams, SocketType } from './ShaderNode';
import { WebGLRenderer } from 'three';
import ShaderNodeMaterial from '../ShaderNodeMaterial';
import { Scene, Camera, Mesh, BufferGeometry, Group } from 'three';
export interface TexWaveParams<T> extends ShaderNodeParams<T> {
    bands_direction: 'X' | 'Y' | 'Z' | 'DIAGONAL';
    rings_direction: 'X' | 'Y' | 'Z' | 'SPHERICAL';
    wave_profile: 'SIN' | 'SAW' | 'TRI';
    wave_type: 'BANDS' | 'RINGS';
}
/** Generate procedural bands or rings with noise */
export default class TexWave extends ShaderNode implements TexWaveParams<NodeSocket> {
    readonly bands_direction: TexWaveParams<NodeSocket>['bands_direction'];
    readonly rings_direction: TexWaveParams<NodeSocket>['rings_direction'];
    readonly wave_profile: TexWaveParams<NodeSocket>['wave_profile'];
    readonly wave_type: TexWaveParams<NodeSocket>['wave_type'];
    constructor(params: TexWaveParams<SocketType>, nodeTree: ShaderNodeTree);
    get defaultUniform(): Map<string, NodeSocket>;
    get parsShader(): string;
    onBeforeObjectRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, object: Mesh, geometry: BufferGeometry, material: ShaderNodeMaterial, group: Group): void;
    onBeforeRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, material: ShaderNodeMaterial): void;
}
