import ShaderNodeTree from '../ShaderNodeTree';
import ShaderNode, { NodeSocket, ShaderNodeParams, SocketType } from './ShaderNode';
import { WebGLRenderer } from 'three';
import ShaderNodeMaterial from '../ShaderNodeMaterial';
import { Scene, Camera, Mesh, BufferGeometry, Group } from 'three';
export interface VectorTransformParams<T> extends ShaderNodeParams<T> {
    /** Space to convert from */
    convert_from: 'WORLD' | 'OBJECT' | 'CAMERA';
    /** Space to convert to */
    convert_to: 'WORLD' | 'OBJECT' | 'CAMERA';
    vector_type: 'POINT' | 'VECTOR' | 'NORMAL';
}
/**
 * Convert a vector, point, or normal between world, camera, and object coordinate
 * space
 */
export default class VectorTransform extends ShaderNode implements VectorTransformParams<NodeSocket> {
    readonly convert_from: VectorTransformParams<NodeSocket>['convert_from'];
    readonly convert_to: VectorTransformParams<NodeSocket>['convert_to'];
    readonly vector_type: VectorTransformParams<NodeSocket>['vector_type'];
    static readonly type = "VECT_TRANSFORM";
    get type(): string;
    constructor(params: VectorTransformParams<SocketType>, nodeTree: ShaderNodeTree);
    get parsShader(): string;
    onBeforeObjectRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, object: Mesh, geometry: BufferGeometry, material: ShaderNodeMaterial, group: Group): void;
    onBeforeRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, material: ShaderNodeMaterial): void;
}
