import ShaderNodeTree from '../ShaderNodeTree';
import ShaderNode, { NodeSocket, ShaderNodeParams, SocketType } from './ShaderNode';
import { WebGLRenderer } from 'three';
import ShaderNodeMaterial from '../ShaderNodeMaterial';
import { Scene, Camera, Mesh, BufferGeometry, Group } from 'three';
export interface WireframeParams<T> extends ShaderNodeParams<T> {
    /** Use screen pixel size instead of world units */
    use_pixel_size: boolean;
}
/**
 * Retrieve the edges of an object as it appears to Cycles.
 * Note: as meshes are triangulated before being processed by Cycles, topology will
 * always appear triangulated
 */
export default class Wireframe extends ShaderNode implements WireframeParams<NodeSocket> {
    readonly use_pixel_size: WireframeParams<NodeSocket>['use_pixel_size'];
    constructor(params: WireframeParams<SocketType>, nodeTree: ShaderNodeTree);
    get defaultUniform(): Map<string, NodeSocket>;
    get parsShader(): string;
    onBeforeObjectRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, object: Mesh, geometry: BufferGeometry, material: ShaderNodeMaterial, group: Group): void;
}
