import { BufferGeometry, Camera, Group, Material, Object3D, Scene, Vector3, WebGLRenderer } from 'three';
import Constraint, { ConstraintParams } from './Constraint';
declare type MapType = 'LOCATION' | 'ROTATION' | 'SCALE';
declare type Axis = 'X' | 'Y' | 'Z';
export interface TransformConstraintParams extends ConstraintParams {
    target?: Object3D;
    from_max: [number, number, number];
    from_min: [number, number, number];
    map_from: MapType;
    map_to: MapType;
    map_to_from: [Axis, Axis, Axis];
    to_max: [number, number, number];
    to_min: [number, number, number];
    use_motion_extrapolate: boolean;
}
declare const targetSymbol: unique symbol;
/** 物体约束：变换 */
export default class TransformConstraint extends Constraint {
    readonly type = "TRANSFORM";
    private [targetSymbol]?;
    set target(target: Object3D | undefined);
    get target(): Object3D | undefined;
    from_max: Vector3;
    from_min: Vector3;
    map_from: MapType;
    map_to: MapType;
    map_to_from: [Axis, Axis, Axis];
    to_max: Vector3;
    to_min: Vector3;
    use_motion_extrapolate: boolean;
    private location;
    private rotation;
    private scale;
    private limitFactor;
    private oldDeltaFactor;
    private deltaFactor;
    constructor(params: TransformConstraintParams);
    private updateLimitFactor;
    private getDeltaData;
    onBeforeRender(renderer: WebGLRenderer, scene: Scene, camera: Camera, object: Object3D, geometry: BufferGeometry, material: Material, group: Group): void;
}
export {};
